==> com_sppagebuilder_pro_v3.0.4.zip: admin/helpers/language.php <==
<?php
/**
 * @package SP Page Builder
 * @author JoomShaper http://www.joomshaper.com
 * @copyright Copyright (c) 2010 - 2016 JoomShaper
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
*/
//no direct accees
defined ('_JEXEC') or die ('restricted aceess');

// Common
JText::script('COM_SPPAGEBUILDER_FRONTEND_EDITOR');
JText::script('COM_SPPAGEBUILDER_PREVIEW');
JText::script('COM_SPPAGEBUILDER_APPLY');
JText::script('COM_SPPAGEBUILDER_CANCEL');

// Media Manager
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_UPLOAD_FILES');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CLOSE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_INSERT');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_SEARCH');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CANCEL');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_DELETE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CONFIRM_DELETE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_LOAD_MORE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_UNSUPPORTED_FORMAT');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_BROWSE_MEDIA');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_BROWSE_FOLDERS');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CREATE_FOLDER');
JText::script('COM_SPPAGEBUILDER_ADDON_ICON_SELECT');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_ENTER_DIRECTORY_NAME');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_MEDIA_UPLOADING');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_UPLOAD_FAILED');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_MEDIA_LARGE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_FILE_NOT_SUPPORTED');

// Row
JText::script('COM_SPPAGEBUILDER_ROW_OPTIONS');
JText::script('COM_SPPAGEBUILDER_ADD_NEW_ROW');
JText::script('COM_SPPAGEBUILDER_DUPLICATE_ROW');
JText::script('COM_SPPAGEBUILDER_DISABLE_ROW');
JText::script('COM_SPPAGEBUILDER_ENABLE_ROW');
JText::script('COM_SPPAGEBUILDER_COPY_ROW');
JText::script('COM_SPPAGEBUILDER_ROW_COPIED');
JText::script('COM_SPPAGEBUILDER_PASTED');
JText::script('COM_SPPAGEBUILDER_PASTE_ROW');
JText::script('COM_SPPAGEBUILDER_DELETE_ROW');
JText::script('COM_SPPAGEBUILDER_ROW_TOGGLE');
JText::script('COM_SPPAGEBUILDER_DELETE_ROW_CONFIRMATION');
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_MANAGEMENT');
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_CUSTOM');
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_GENERATE');
JText::script('COM_SPPAGEBUILDER_IMPORT_PAGE');
JText::script('COM_SPPAGEBUILDER_IMPORT_PAGE_ALT');
JText::script('COM_SPPAGEBUILDER_EXPORT_PAGE');
JText::script('COM_SPPAGEBUILDER_PAGE_TEMPLATES');
JText::script('COM_SPPAGEBUILDER_UNDO');
JText::script('COM_SPPAGEBUILDER_REDO');
JText::script('COM_SPPAGEBUILDER_SAVE');
JText::script('COM_SPPAGEBUILDER_SAVE_ROW');

//Addon
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_OPTIONS');
JText::script('COM_SPPAGEBUILDER_DELETE_COLUMN');
JText::script('COM_SPPAGEBUILDER_ADD_NEW_ADDON');
JText::script('COM_SPPAGEBUILDER_ADDON');
JText::script('COM_SPPAGEBUILDER_DELETE_ADDON');
JText::script('COM_SPPAGEBUILDER_DUPLICATE_ADDON');
JText::script('COM_SPPAGEBUILDER_EDIT_ADDON');
JText::script('COM_SPPAGEBUILDER_ADDONS_LIST');
JText::script('COM_SPPAGEBUILDER_ALL');
JText::script('COM_SPPAGEBUILDER_MODAL_CLOSE');
JText::script('COM_SPPAGEBUILDER_DISABLE_COLUMN');
JText::script('COM_SPPAGEBUILDER_ENABLE_COLUMN');

JText::script('COM_SPPAGEBUILDER_YES');
JText::script('COM_SPPAGEBUILDER_NO');
JText::script('COM_SPPAGEBUILDER_PAGE_TEMPLATES_LIST');
JText::script('COM_SPPAGEBUILDER_PAGE_TEMPLATE_LOAD');
JText::script('COM_SPPAGEBUILDER_ENABLE_ADDON');
JText::script('COM_SPPAGEBUILDER_DISABLE_ADDON');
JText::script('COM_SPPAGEBUILDER_ADDON_PARENT_COLUMN');
JText::script('COM_SPPAGEBUILDER_ADD_NEW_INNER_ROW');
JText::script('COM_SPPAGEBUILDER_MOVE_COLUMN');

JText::script('COM_SPPAGEBUILDER_DAY');
JText::script('COM_SPPAGEBUILDER_DAYS');
JText::script('COM_SPPAGEBUILDER_HOUR');
JText::script('COM_SPPAGEBUILDER_HOURS');
JText::script('COM_SPPAGEBUILDER_MINUTE');
JText::script('COM_SPPAGEBUILDER_MINUTES');
JText::script('COM_SPPAGEBUILDER_SECOND');
JText::script('COM_SPPAGEBUILDER_SECONDS');

JText::script('COM_SPPAGEBUILDER_ADDON_OPTIN_FORM_SUBCSCRIBE');
JText::script('COM_SPPAGEBUILDER_ADDON_AJAX_CONTACT_NAME');
JText::script('COM_SPPAGEBUILDER_ADDON_AJAX_CONTACT_EMAIL');

==> com_sppagebuilder_pro_v3.1.3.zip: admin/helpers/language.php <==
<?php
/**
 * @package SP Page Builder
 * @author JoomShaper http://www.joomshaper.com
 * @copyright Copyright (c) 2010 - 2016 JoomShaper
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
*/
//no direct accees
defined ('_JEXEC') or die ('Restricted access');

// Common
JText::script('COM_SPPAGEBUILDER_FRONTEND_EDITOR');
JText::script('COM_SPPAGEBUILDER_PREVIEW');
JText::script('COM_SPPAGEBUILDER_APPLY');
JText::script('COM_SPPAGEBUILDER_CANCEL');

// Media Manager
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_UPLOAD_FILES');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CLOSE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_INSERT');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_SEARCH');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CANCEL');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_DELETE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CONFIRM_DELETE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_LOAD_MORE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_UNSUPPORTED_FORMAT');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_BROWSE_MEDIA');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_BROWSE_FOLDERS');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_CREATE_FOLDER');
JText::script('COM_SPPAGEBUILDER_ADDON_ICON_SELECT');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_ENTER_DIRECTORY_NAME');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_MEDIA_UPLOADING');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_UPLOAD_FAILED');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_MEDIA_LARGE');
JText::script('COM_SPPAGEBUILDER_MEDIA_MANAGER_FILE_NOT_SUPPORTED');

// Row
JText::script('COM_SPPAGEBUILDER_ROW_OPTIONS');
JText::script('COM_SPPAGEBUILDER_ADD_NEW_ROW');
JText::script('COM_SPPAGEBUILDER_DUPLICATE_ROW');
JText::script('COM_SPPAGEBUILDER_DISABLE_ROW');
JText::script('COM_SPPAGEBUILDER_ENABLE_ROW');
JText::script('COM_SPPAGEBUILDER_COPY_ROW');
JText::script('COM_SPPAGEBUILDER_ROW_COPIED');
JText::script('COM_SPPAGEBUILDER_PASTED');
JText::script('COM_SPPAGEBUILDER_PASTE_ROW');
JText::script('COM_SPPAGEBUILDER_DELETE_ROW');
JText::script('COM_SPPAGEBUILDER_ROW_TOGGLE');
JText::script('COM_SPPAGEBUILDER_DELETE_ROW_CONFIRMATION');
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_MANAGEMENT');
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_CUSTOM');
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_GENERATE');
JText::script('COM_SPPAGEBUILDER_IMPORT_PAGE');
JText::script('COM_SPPAGEBUILDER_IMPORT_PAGE_ALT');
JText::script('COM_SPPAGEBUILDER_EXPORT_PAGE');
JText::script('COM_SPPAGEBUILDER_PAGE_TEMPLATES');
JText::script('COM_SPPAGEBUILDER_UNDO');
JText::script('COM_SPPAGEBUILDER_REDO');
JText::script('COM_SPPAGEBUILDER_SAVE');
JText::script('COM_SPPAGEBUILDER_SAVE_ROW');

//Addon
JText::script('COM_SPPAGEBUILDER_ROW_COLUMNS_OPTIONS');
JText::script('COM_SPPAGEBUILDER_DELETE_COLUMN');
JText::script('COM_SPPAGEBUILDER_ADD_NEW_ADDON');
JText::script('COM_SPPAGEBUILDER_ADDON');
JText::script('COM_SPPAGEBUILDER_DELETE_ADDON');
JText::script('COM_SPPAGEBUILDER_DUPLICATE_ADDON');
JText::script('COM_SPPAGEBUILDER_EDIT_ADDON');
JText::script('COM_SPPAGEBUILDER_ADDONS_LIST');
JText::script('COM_SPPAGEBUILDER_ALL');
JText::script('COM_SPPAGEBUILDER_MODAL_CLOSE');
JText::script('COM_SPPAGEBUILDER_DISABLE_COLUMN');
JText::script('COM_SPPAGEBUILDER_ENABLE_COLUMN');

JText::script('COM_SPPAGEBUILDER_YES');
JText::script('COM_SPPAGEBUILDER_NO');
JText::script('COM_SPPAGEBUILDER_PAGE_TEMPLATES_LIST');
JText::script('COM_SPPAGEBUILDER_PAGE_TEMPLATE_LOAD');
JText::script('COM_SPPAGEBUILDER_ENABLE_ADDON');
JText::script('COM_SPPAGEBUILDER_DISABLE_ADDON');
JText::script('COM_SPPAGEBUILDER_SAVE_ADDON');
JText::script('COM_SPPAGEBUILDER_ADDON_PARENT_COLUMN');
JText::script('COM_SPPAGEBUILDER_ADD_NEW_INNER_ROW');
JText::script('COM_SPPAGEBUILDER_MOVE_COLUMN');

JText::script('COM_SPPAGEBUILDER_DAY');
JText::script('COM_SPPAGEBUILDER_DAYS');
JText::script('COM_SPPAGEBUILDER_HOUR');
JText::script('COM_SPPAGEBUILDER_HOURS');
JText::script('COM_SPPAGEBUILDER_MINUTE');
JText::script('COM_SPPAGEBUILDER_MINUTES');
JText::script('COM_SPPAGEBUILDER_SECOND');
JText::script('COM_SPPAGEBUILDER_SECONDS');

JText::script('COM_SPPAGEBUILDER_ADDON_OPTIN_FORM_SUBCSCRIBE');
JText::script('COM_SPPAGEBUILDER_ADDON_AJAX_CONTACT_NAME');
JText::script('COM_SPPAGEBUILDER_ADDON_AJAX_CONTACT_EMAIL');
